pynaf
=====

Pynaf provides  **a simple API for creating or reading NAF documents**.

The NAF (Natural language Annotation Format) is **an XML markup language that contains several layers of linguistic annotation**. It is used in **Natural Language Processing tools** like [IXA Pipes] (http://ixa2.si.ehu.es/ixa-pipes/) or [Corefgraph](https://bitbucket.org/Josu/corefgraph).

**More information** about NAF in the  following [link ](https://github.com/newsreader/NAF).


Install from Pip(Recommended)
----
Install pinaf directly from Pypi repositories

    Pip install pynaf


Install from repository
-----

Install pynaf using this command (no need to clone the repository):

    pip install --upgrade --user git+https://github.com/josubg/pynaf.git
